@@ -93,7 +93,7 @@ void Export_pyste_src_Image()
         .def("colorize", (void (Magick::Image::*)(const unsigned int, const unsigned int, const unsigned int, const Magick::Color&) )&Magick::Image::colorize)
         .def("colorize", (void (Magick::Image::*)(const unsigned int, const Magick::Color&) )&Magick::Image::colorize)
         .def("comment", (void (Magick::Image::*)(const std::string&) )&Magick::Image::comment)
-        .def("compare", &Magick::Image::compare)
+        .def("compare", (bool (Magick::Image::*)(const Magick::Image&) )&Magick::Image::compare)
         .def("composite", (void (Magick::Image::*)(const Magick::Image&, const ::ssize_t, const ::ssize_t, const MagickCore::CompositeOperator) )&Magick::Image::composite, Magick_Image_composite_overloads_3_4())
         .def("composite", (void (Magick::Image::*)(const Magick::Image&, const Magick::Geometry&, const MagickCore::CompositeOperator) )&Magick::Image::composite, Magick_Image_composite_overloads_2_3())
         .def("composite", (void (Magick::Image::*)(const Magick::Image&, const MagickCore::GravityType, const MagickCore::CompositeOperator) )&Magick::Image::composite, Magick_Image_composite_overloads_2_3())
@@ -115,7 +115,9 @@ void Export_pyste_src_Image()
         .def("floodFillColor", (void (Magick::Image::*)(const Magick::Geometry&, const Magick::Color&) )&Magick::Image::floodFillColor)
         .def("floodFillColor", (void (Magick::Image::*)(const ::ssize_t, const ::ssize_t, const Magick::Color&, const Magick::Color&) )&Magick::Image::floodFillColor)
         .def("floodFillColor", (void (Magick::Image::*)(const Magick::Geometry&, const Magick::Color&, const Magick::Color&) )&Magick::Image::floodFillColor)
-        .def("floodFillOpacity", &Magick::Image::floodFillOpacity)
+        .def("floodFillOpacity", (void (Magick::Image::*)(const ::ssize_t, const ::ssize_t, const unsigned int, const bool) ) &Magick::Image::floodFillOpacity)
+        .def("floodFillOpacity", (void (Magick::Image::*)(const ::ssize_t, const ::ssize_t, const unsigned int, const Magick::PaintMethod) ) &Magick::Image::floodFillOpacity)
+        .def("floodFillOpacity", (void (Magick::Image::*)(const ::ssize_t, const ::ssize_t, const unsigned int, const Magick::Color&, const bool) ) &Magick::Image::floodFillOpacity)
         .def("floodFillTexture", (void (Magick::Image::*)(const ::ssize_t, const ::ssize_t, const Magick::Image&) )&Magick::Image::floodFillTexture)
         .def("floodFillTexture", (void (Magick::Image::*)(const Magick::Geometry&, const Magick::Image&) )&Magick::Image::floodFillTexture)
         .def("floodFillTexture", (void (Magick::Image::*)(const ::ssize_t, const ::ssize_t, const Magick::Image&, const Magick::Color&) )&Magick::Image::floodFillTexture)
